BackendTypes

Trait BackendTypes 

pub trait BackendTypes {
    type Device: DeviceOps;
    type FloatTensorPrimitive: TensorMetadata + 'static;
    type FloatElem: Element;
    type IntTensorPrimitive: TensorMetadata + 'static;
    type IntElem: Element;
    type BoolTensorPrimitive: TensorMetadata + 'static;
    type BoolElem: Element;
    type QuantizedTensorPrimitive: TensorMetadata + QTensorPrimitive + 'static;
}
The mapping of types used by Backend and traits like Numeric, BasicOps

Required Associated Types

type Device: DeviceOps

Device type.

type FloatTensorPrimitive: TensorMetadata + 'static

Tensor primitive to be used for all float operations.

type FloatElem: Element

Default float element type.

type IntTensorPrimitive: TensorMetadata + 'static

Tensor primitive to be used for all int operations.

type IntElem: Element

Int element type.

type BoolTensorPrimitive: TensorMetadata + 'static

Tensor primitive to be used for all bool operations.

type BoolElem: Element

Tensor primitive to be used for all bool operations.

type QuantizedTensorPrimitive: TensorMetadata + QTensorPrimitive + 'static

Tensor primitive to be used for all quantized operations.

Implementors