pub type DTypeUsageSet = EnumSet<DTypeUsage>;Expand description
A set of DTypeUsage representing the total capabilities of a data type on a device.
Aliased Type
pub struct DTypeUsageSet { /* private fields */ }pub type DTypeUsageSet = EnumSet<DTypeUsage>;A set of DTypeUsage representing the total capabilities of a data type on a device.
pub struct DTypeUsageSet { /* private fields */ }