pub struct TensorContainer<ID> { /* private fields */ }Expand description
Contains tensor of arbitrary dimension.
Implementations
Sourceimpl<ID> TensorContainer<ID>
impl<ID> TensorContainer<ID>
Sourcepub fn new() -> TensorContainer<ID>
pub fn new() -> TensorContainer<ID>
Create an empty container.
Sourcepub fn get_mut_ref<T>(&mut self, id: &ID) -> Option<&mut T>
pub fn get_mut_ref<T>(&mut self, id: &ID) -> Option<&mut T>
Get a mutable reference to the tensor with the given ID.
Sourcepub fn register<T>(&mut self, id: ID, value: T)
pub fn register<T>(&mut self, id: ID, value: T)
Register a new tensor for the given ID.
Notes
If a tensor is already registered for the given ID, it will be replaced.