Module distributed

Module distributed 

Available on crate feature std only.
Distributed execution utilities.

The core component of this module is DistributedContext, which manages the lifecycle of distributed synchronization clients.

Structs

CollectiveTensor
A tensor handle used for a collective operation, that is not yet valid for use. We must ensure collective operations are completed before accessing the underlying data.
DistributedConfig
Parameter struct for setting up and getting parameters for distributed operations.
DistributedContext
This structure acts as a resource handle for multi-device synchronization.

Enums

ReduceOperation
The different ways to execute the reduce operation.

Functions

all_reduce
Performs an all_reduce operation on the input tensor.