pub struct CollectiveTensor<const D: usize> { /* private fields */ }Available on crate feature
std only.Expand description
A tensor handle used for a collective operation, that is not yet valid for use. We must ensure collective operations are completed before accessing the underlying data.
Implementations
Sourceimpl<const D: usize> CollectiveTensor<D>
impl<const D: usize> CollectiveTensor<D>
Sourcepub fn new(handle: DispatchTensor) -> Self
pub fn new(handle: DispatchTensor) -> Self
Constructs a new CollectiveTensor.
Sourceimpl<const D: usize> CollectiveTensor<D>
impl<const D: usize> CollectiveTensor<D>
Sourcepub fn resolve(self) -> Tensor<D>
pub fn resolve(self) -> Tensor<D>
Synchronizes the collective operation and returns a valid tensor handle.
Sourcepub unsafe fn assume_resolved(self) -> Tensor<D>
pub unsafe fn assume_resolved(self) -> Tensor<D>
Returns the tensor handle without synchronizing.
Safety
The caller must ensure that sync_collective() is called before
the returned handle is used in any computation.