pub struct QuantConfig {
pub scheme: QuantScheme,
pub propagation: QuantPropagation,
}Expand description
Configuration for a device quantization behavior.
This configuration determines how tensors are quantized and how quantization rules propagate through operations on a given device. It is applied once during device initialization. See also the device settings.
Fields
scheme: QuantSchemeDefines how a tensor is quantized.
propagation: QuantPropagationHow quantization is propagated during computation.
Implementations
Sourceimpl QuantConfig
impl QuantConfig
Sourcepub fn new(scheme: QuantScheme, propagation: QuantPropagation) -> QuantConfig
pub fn new(scheme: QuantScheme, propagation: QuantPropagation) -> QuantConfig
Constructs a new QuantConfig.