pub struct DeviceConfig {
pub float_dtype: Option<FloatDType>,
pub int_dtype: Option<IntDType>,
pub bool_dtype: Option<BoolDType>,
}Expand description
Configuration options used to initialize a device.
Unlike DeviceSettings, this type represents partial user-provided
configuration and does not require all settings to be specified.
Any unspecified options will be resolved to device-specific defaults when the device is initialized.
Use Device::configure to apply this configuration to a device.
Fields
float_dtype: Option<FloatDType>Default floating-point data type.
int_dtype: Option<IntDType>Default integer data type.
bool_dtype: Option<BoolDType>Default boolean data type.
Implementations
Sourceimpl DeviceConfig
impl DeviceConfig
Sourceimpl DeviceConfig
impl DeviceConfig
Sourcepub fn float_dtype(self, dtype: impl Into<FloatDType>) -> Self
pub fn float_dtype(self, dtype: impl Into<FloatDType>) -> Self
Sets the default floating-point data type for tensors created on the device.
Sourcepub fn int_dtype(self, dtype: impl Into<IntDType>) -> Self
pub fn int_dtype(self, dtype: impl Into<IntDType>) -> Self
Sets the default integer data type for tensors created on the device.
Sourcepub fn bool_dtype(self, dtype: impl Into<BoolDType>) -> Self
pub fn bool_dtype(self, dtype: impl Into<BoolDType>) -> Self
Sets the default boolean data type storage precision for tensors created on the device.