TensorCreationOptions

Struct TensorCreationOptions 

pub struct TensorCreationOptions {
    pub device: Device,
    pub dtype: Option<DType>,
}
Options for tensor creation.

This struct allows specifying the device and overriding the data type when creating a tensor. When the dtype is not specified, the device’s default settings is used.

Fields

device: Device

Device where the tensor will be created.

dtype: Option<DType>

Optional data type. If None, the dtype will be inferred on creation from the device settings.

Implementations

Source

impl TensorCreationOptions

pub fn new(device: Device) -> Self

Create new options with a specific device.

Data type will follow the device settings on tensor creation.

pub fn with_dtype(self, dtype: DType) -> Self

Set the tensor creation data type.

pub fn with_device(self, device: Device) -> Self

Set the tensor creation device.

pub fn dtype_or(&self, dtype: DType) -> DType

Returns the tensor data type, or a provided default if not set.

This is useful for cases where TensorCreationOptions may not have an explicit dtype.