SliceArg

Trait SliceArg 

pub trait SliceArg {
    // Required method
    fn into_slices(self, shape: &Shape) -> Vec<Slice>;
}
Trait for slice arguments that can be converted into an array of slices. This allows the slice method to accept both single slices (from s![..]) and arrays of slices (from s![.., ..] or [0..5, 1..3]).

Required Methods

fn into_slices(self, shape: &Shape) -> Vec<Slice>

Convert to an vec of slices with clamping to shape dimensions.

Returns a Slice for each dimension in shape.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl SliceArg for &Vec<Slice>

Source

fn into_slices(self, shape: &Shape) -> Vec<Slice>

Source

impl<S> SliceArg for &[S]
where S: Into<Slice> + Clone,

Source

fn into_slices(self, shape: &Shape) -> Vec<Slice>

Source

impl<const R: usize, T> SliceArg for [T; R]
where T: Into<Slice> + Clone,

Source

fn into_slices(self, shape: &Shape) -> Vec<Slice>

Implementors

Source

impl<T> SliceArg for T
where T: Into<Slice>,