pub trait BackendTypes {
type Device: DeviceOps;
type FloatTensorPrimitive: TensorMetadata + 'static;
type FloatElem: Element;
type IntTensorPrimitive: TensorMetadata + 'static;
type IntElem: Element;
type BoolTensorPrimitive: TensorMetadata + 'static;
type BoolElem: Element;
type QuantizedTensorPrimitive: TensorMetadata + QTensorPrimitive + 'static;
}Expand description
The mapping of types used by Backend and traits like Numeric, BasicOps
Required Associated Types
Sourcetype FloatTensorPrimitive: TensorMetadata + 'static
type FloatTensorPrimitive: TensorMetadata + 'static
Tensor primitive to be used for all float operations.
Sourcetype IntTensorPrimitive: TensorMetadata + 'static
type IntTensorPrimitive: TensorMetadata + 'static
Tensor primitive to be used for all int operations.
Sourcetype BoolTensorPrimitive: TensorMetadata + 'static
type BoolTensorPrimitive: TensorMetadata + 'static
Tensor primitive to be used for all bool operations.
Sourcetype QuantizedTensorPrimitive: TensorMetadata + QTensorPrimitive + 'static
type QuantizedTensorPrimitive: TensorMetadata + QTensorPrimitive + 'static
Tensor primitive to be used for all quantized operations.