Available on crate feature
std only.Expand description
Distributed execution utilities.
The core component of this module is DistributedContext, which manages
the lifecycle of distributed synchronization clients.
Structs
- Collective
Tensor - A tensor handle used for a collective operation, that is not yet valid for use. We must ensure collective operations are completed before accessing the underlying data.
- Distributed
Config - Parameter struct for setting up and getting parameters for distributed operations.
- Distributed
Context - This structure acts as a resource handle for multi-device synchronization.
Enums
- Reduce
Operation - The different ways to execute the reduce operation.
Functions
- all_
reduce - Performs an all_reduce operation on the input tensor.