pub enum DeviceError {
UnsupportedDType {
device: String,
dtype: DType,
},
}Expand description
Errors that can occur during device-related operations.
This covers errors related to hardware capability mismatches, such as requesting a data type not supported by the device, and configuration errors like attempting to change a policy in an invalid context.
Variants
UnsupportedDType
Unsupported data type by the device.
Implementations
Sourceimpl DeviceError
impl DeviceError
Sourcepub fn unsupported_dtype<D: DeviceOps>(device: &D, dtype: DType) -> Self
pub fn unsupported_dtype<D: DeviceOps>(device: &D, dtype: DType) -> Self
Helper to create a DeviceError::UnsupportedDType from any device.