pub trait SliceArg {
// Required method
fn into_slices(self, shape: &Shape) -> Vec<Slice>;
}Expand description
Trait for slice arguments that can be converted into an array of slices.
This allows the slice method to accept both single slices (from s![..])
and arrays of slices (from s![.., ..] or [0..5, 1..3]).
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".